import pilas

pilas.iniciar()
pilas.fondos.Pasto()
pilas.avisar('Use Alt+q para salir.')

actor = pilas.actores.Actor("data/logo.png")

pilas.ejecutar()
